The Cabin font family is a humanist sans with 4 weights and true italics, inspired by Edward Johnston’s and Eric Gill’s typefaces, with a touch of modernism. Cabin incorporates modern proportions, optical adjustments, and some elements of the geometric sans. It remains true to its roots, but has its own personality. The weight distribution is almost monotone, although top and bottom curves are slightly thin. Counters of the b, g, p and q are rounded and optically adjusted. The curved stem endings have a 10 degree angle. E and F have shorter center arms. M is splashed.

Updated: January 2016 to version 1.007